summaryrefslogtreecommitdiff
path: root/src/tileset.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/tileset.h')
-rw-r--r--src/tileset.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/tileset.h b/src/tileset.h
index 27bc28c3..7521a3e5 100644
--- a/src/tileset.h
+++ b/src/tileset.h
@@ -24,19 +24,19 @@
#ifndef _TMW_TILESET_H_
#define _TMW_TILESET_H_
-#include "resources/spriteset.h"
+#include "resources/imageset.h"
/**
* A tileset, which is basically just a spriteset but it stores a firstgid.
*/
-class Tileset : public Spriteset
+class Tileset : public ImageSet
{
public:
/**
* Constructor.
*/
Tileset(Image *img, int w, int h, int firstGid):
- Spriteset("", img, w, h),
+ ImageSet("", img, w, h),
mFirstGid(firstGid)
{
}
@@ -24,19 +24,19 @@
/**
- * A tileset, which is basically just a spriteset but it stores a firstgid.
+ * A tileset, which is basically just an image set but it stores a firstgid.
*/